#
# spec file for package openais (Version 0.80.6)
#
# Copyright (c) 2008 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild

%if 0%{?suse_version}
%define _libexecdir %{_libdir}
%endif
%define ais_uid         39
%define ais_user	ais
%if 0%{?fedora_version}
%define pkg_group System Environment/Base
%else
%define pkg_group Productivity/Clustering/HA
%endif

Name:           openais
Summary:        The OpenAIS Standards-Based Cluster Framework executive and APIs
Version:        0.80.6
Release:        15.1
License:        BSD 3-Clause
Group:          %{pkg_group}
Url:            http://www.openais.org/
Source:         openais.tar.gz
Patch1:         suse.diff
Patch2:         openais-init.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(pre):   /usr/sbin/useradd
Requires(post):  /sbin/chkconfig
Requires(preun): /sbin/chkconfig

%description 
This package contains the openais executive, openais service handlers,
default configuration files and init script.



Authors:
--------
    Steven Dake
    Mark Haverkamp
    Muni Bajpai
    Daniel McNiel
    Miyotaka Sakai
    Daniel Stodden
    Kristen Smith
    Patrick Caulfield
    Fabien Thomas
    Hans Feldt
    Lars Holm
    Anders Eriksson
    Renaud Metrich
    Frederic Hermann
    Alejandro Lopez
    David Teigland
    Robert Peterson
    Abhijith Das

%package -n libopenais2
License:        BSD 3-Clause
Summary:        The OpenAIS Standards-Based Cluster Framework executive and APIs
Group:          %{pkg_group}

%description -n libopenais2
This package contains the openais executive, openais service handlers,
default configuration files and init script.



Authors:
--------
    Steven Dake
    Mark Haverkamp
    Muni Bajpai
    Daniel McNiel
    Miyotaka Sakai
    Daniel Stodden
    Kristen Smith
    Patrick Caulfield
    Fabien Thomas
    Hans Feldt
    Lars Holm
    Anders Eriksson
    Renaud Metrich
    Frederic Hermann
    Alejandro Lopez
    David Teigland
    Robert Peterson
    Abhijith Das

%package -n libopenais-devel
License:        BSD 3-Clause
Summary:        The openais Standards-Based Cluster Framework libraries
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}-%{release}
Requires:       libopenais2 = %{version}-%{release}

%description -n libopenais-devel
This package contains the libraries and include files used to develop
using openais APIs.



Authors:
--------
    Steven Dake
    Mark Haverkamp
    Muni Bajpai
    Daniel McNiel
    Miyotaka Sakai
    Daniel Stodden
    Kristen Smith
    Patrick Caulfield
    Fabien Thomas
    Hans Feldt
    Lars Holm
    Anders Eriksson
    Renaud Metrich
    Frederic Hermann
    Alejandro Lopez
    David Teigland
    Robert Peterson
    Abhijith Das

%prep
%setup -n openais
%patch1 -p0
%patch2 -p1

%build
# -O3 required for performance reasons
# So we get proper debug output, for now we don't compile with O3
#CFLAGS="$(echo '%{optflags}' | sed -e 's/-O[0-9]*//') -O3"
#CFLAGS="$(echo '%{optflags}')"
make CFLAGS="$RPM_OPT_FLAGS" LIBDIR=%{_libdir}/openais LCRSODIR=%{_libexecdir}/lcrso PREFIX=%{_prefix} OPENAIS_BUILD=DEBUG

%install
rm -rf $RPM_BUILD_ROOT
make LIBDIR=%{_libdir}/openais DESTDIR=$RPM_BUILD_ROOT PREFIX=%{_prefix} LCRSODIR=%{_libexecdir}/lcrso STATICLIBS=NO OPENAIS_BUILD=DEBUG install
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
mkdir -p $RPM_BUILD_ROOT%{_initrddir}
install -m 644 CHANGELOG LICENSE SECURITY README.devmap README.amf \
	$RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/
install -m 755 init/generic $RPM_BUILD_ROOT%{_initrddir}/openais
install -m 755 test/openais-cfgtool $RPM_BUILD_ROOT%{_sbindir}
find $RPM_BUILD_ROOT -name '*.a' -type f -print0 | xargs -0 rm -f
find $RPM_BUILD_ROOT -name '*.la' -type f -print0 | xargs -0 rm -f
%if 0%{?suse_version}
ln -sf ../../etc/init.d/openais $RPM_BUILD_ROOT/%{_sbindir}/rcopenais
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%pre
%if 0%{?fedora_version}
/usr/sbin/fedora-useradd %{ais_uid} -r -s /sbin/nologin -d '/' -M \
        -c 'openais Standards Based Cluster Framework' %{ais_user} &>/dev/null || :
%else
if
  getent passwd %{ais_user} >/dev/null
then
  : OK hacluster user already present
else
  /usr/sbin/useradd -c "openais Standards Based Cluster Framework" \
      -r -d '/' -u %{ais_uid} %{ais_user} 2>/dev/null || :
fi
%endif

%post
%if 0%{?suse_version}
  %{fillup_and_insserv -n openais}
%else
  /sbin/chkconfig --add openais || :
%endif

%preun
%if 0%{?suse_version}
  %stop_on_removal openais
%else
if [ $1 -eq 0 ]; then
  %{_initrddir}/openais stop &>/dev/null || :
fi
%endif
/sbin/chkconfig --del openais || :

%postun
%if 0%{?suse_version}
  %restart_on_update openais
  %{insserv_cleanup}
%else
[ "$1" -ge "1" ] && %{_initrddir}/openais condrestart &>/dev/null || :
%endif

%post -n libopenais2 -p /sbin/ldconfig

%postun -n libopenais2 -p /sbin/ldconfig

%files 
%defattr(-,root,root,-)
%dir %{_docdir}/%{name}-%{version}
%doc %{_docdir}/%{name}-%{version}/LICENSE
%doc %{_docdir}/%{name}-%{version}/SECURITY
%doc %{_docdir}/%{name}-%{version}/README.amf
%{_sbindir}/aisexec
%{_sbindir}/ais-keygen
%{_sbindir}/openais-cfgtool
%dir /etc/ais
%config(noreplace) /etc/ais/openais.conf
%config(noreplace) /etc/ais/amf.conf
%config /etc/ld.so.conf.d/openais-*.conf
%{_initrddir}/openais
%if 0%{?suse_version}
%{_sbindir}/rcopenais
%endif
%dir %{_libexecdir}/lcrso
%{_libexecdir}/lcrso/*.lcrso
%{_mandir}/man8/*.8*
%{_mandir}/man5/openais.conf.5*

%files -n libopenais2
%defattr(-,root,root,-)
%dir %{_libdir}/openais
%{_libdir}/openais/lib*.so.*

%files -n libopenais-devel
%defattr(-,root,root,-)
%dir %{_docdir}/%{name}-%{version}
%doc %{_docdir}/%{name}-%{version}/CHANGELOG
%doc %{_docdir}/%{name}-%{version}/README.devmap
%dir %{_includedir}/openais/
%dir %{_includedir}/openais/lcr/
%dir %{_includedir}/openais/totem/
%dir %{_includedir}/openais/service
%{_libdir}/openais/lib*.so
%{_includedir}/openais/*.h
%{_includedir}/openais/lcr/*.h
%{_includedir}/openais/totem/*.h
%{_includedir}/openais/service/*.h
%{_mandir}/man3/cpg_*.3*
%{_mandir}/man3/evs_*.3*

%changelog
* Sun Apr 12 2009 Andrew Beekhof <abeekhof@suse.de>
- version 0.80.5-1
- Update patch to upstream r1791
+ Fix when dispatch has error condition to execute a put on the handle as
+ Keep mulitple threads out of the aisexec service engines.
+ This patch fixes a crash in cpg.c where a group is left befopre
+ sched_setscheduler was commented out in previous commit.
+ Serialize ipc access so only one thread accesses a service engine at a
+ Remove pass by value in the ckpt service.
+ Patch to fix refcounting problem for checkpoints from leaving nodes.
+ Prevent logging deadlocks due to fork() in service engines.
+ CPGs with large node IDS greater then 0xffffff would not synchronize
+ The ckpt service with new versions of openais would segfault with older
+ Delete process info from list parsing if ipc connection dies.  This
+ Remove reserved count from totempg_mcast operations.
+ change totempg interface to allow for reserve and release instead of
+ changes structure of ipc system to allow reference counting in
+ Fix IPC reference counting in cpg service.
+ Add generic init script for openais.
+ Add loading of modules support to openais whitetank.
+ Bounds checking of the messages in the IPC system with core dump
+ Use definition instead of magic number.
+ Backport the minimal set of objdb changes from corosync that are
+ IPC Redesign and rewrite.
+ Avoid totem overflow in send_ok when the totempg header is larger then
+ Execute a list_init for the expiry entry on the creation of a checkpoint
+ Execute a proper list_del operation when unlinking a checkpoint so it is
+ Ensure high bit is masked properly.
+ Fix secauth to work properly on platforms which evaluate unsigned long to 8 bytes (s390x).
+ Fix regression in open async of the event service.
+ Throw away incomplete message on startup to avoid segfault.
+ Fix message rejection problem with many services.
+ Make ckptbench work properly by setting section expiration timers to SA_TIME_END.
+ Cancel token hold mode when a totem token callback is added to the system.
+ Correctly compare local addresses with bindnetaddr
+ Use the node's full ipv4 address when generating nodeids
+ Patch to fix segfault when user with inappropriate permissions accesses
* Wed Nov 19 2008 Andrew Beekhof <abeekhof@suse.de>
- version 0.80.3-4
- Update patch to 26c4af74cac1
+ Fix service load order patch which prevented openais from starting
* Fri Nov 14 2008 Andrew Beekhof <abeekhof@suse.de>
- version 0.80.3-3
- Update source tarball to r1661
- Update patch to bbbb59907893
+ Fix nodeid generation to use the node's full ip address (not network address) to ensure uniqueness
+ Start additional services after the default ones
+ Correctly compare addresses with bindnetaddr
+ Fix a message lost during delivery which resulted in checkpoint segfault
+ Fix commit token recieved_flg being incorrect in some rare circumstances
+ Fix rare problem where checkpoint synchronization database could be thrown away
+ Improvements to the default openais.conf file
+ Add a configuraiton option to allow generated nodeids to be limited to 31-bits
* Thu Oct  9 2008 Andrew Beekhof <abeekhof@suse.de>
- version 0.80.3-2
- Update source tarball to r1655
+ Remove IPC scheduling starvation
+ Fix Library queue full messages in some conditions
+ Make sanitizing generated nodeid's optional
+ Create a libopenais2 subpackage as per policy
* Wed Aug 20 2008 Andrew Beekhof <abeekhof@suse.de>
- version 0.80.3-1
- Update source tarball to r1649
+ Add backports of objdb and service shutdown patches
+ Modify the nodeid generation function to never return a negative value
* Mon Sep 24 2007 Andrew Beekhof <abeekhof@suse.de>
- version 0.83-12
- Update the source tarball to revision 1495
+ make install now works properly on systems which produce wierd uname results
+ Patch to not increment the ring seq id on the first operational ring.
+ Remove & when regular reference works properly.
+ Patch to set system from field properly in retransmitted messages.
+ Make sure to unlock the handle database on a failure condition.
+ Properly daemonize and dup file descriptors to /dev/null.
+ Patch to make sure make clean works as advertised.
+ fix install broken when O=<DIR> is used
+ Allow multiple config plugins to be loaded at start time and set the config
  object database objects.
+ Force logging to stderr if the -f flag is specified.
+ srcdir is not set when realpath & abspath don't work
+ Remove closing of ttys that slipped in improperly.
+ Patch to install liblogsys
* Mon Sep 24 2007 Andrew Beekhof <abeekhof@suse.de>
- version 0.83-12
- Update the source tarball to revision 1480
- Add patches for dynamic load/unload and crm startup/shutdown
* Mon Sep 24 2007 Andrew Beekhof <abeekhof@suse.de>
- version 0.83-1
- Initial version for the build service
- Update the source tarball to revision 1452
